[openib-general] [PATCH][3/19] kDAPL: Remove typedef DAT_QOS

Tom Duffy Tom.Duffy at Sun.COM
Sun May 15 11:27:16 PDT 2005


Signed-off-by: Tom Duffy <tduffy at sun.com>

diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/dat/dat.h linux-kernel3/dat/dat.h
--- linux-kernel2/dat/dat.h	2005-05-13 11:45:56.934001000 -0700
+++ linux-kernel3/dat/dat.h	2005-05-13 12:33:26.944001000 -0700
@@ -412,7 +412,7 @@ typedef u64 DAT_CONN_QUAL;
 typedef u64 DAT_PORT_QUAL;
 
 /* QOS definitions */
-typedef enum dat_qos {
+enum dat_qos {
 	DAT_QOS_BEST_EFFORT = 0x00,
 	DAT_QOS_HIGH_THROUGHPUT = 0x01,
 	DAT_QOS_LOW_LATENCY = 0x02,
@@ -420,7 +420,7 @@ typedef enum dat_qos {
 	DAT_QOS_ECONOMY = 0x04,
 	/* both low latency and high throughput */
 	DAT_QOS_PREMIUM = 0x08
-} DAT_QOS;
+};
 
 /*
  * FLAGS
@@ -560,7 +560,7 @@ struct dat_rmr_param {
 struct dat_ep_attr {
 	u64 max_message_size;
 	u64 max_rdma_size;
-	DAT_QOS qos;
+	enum dat_qos qos;
 	DAT_COMPLETION_FLAGS recv_completion_flags;
 	DAT_COMPLETION_FLAGS request_completion_flags;
 	int max_recv_dtos;
@@ -1064,7 +1064,7 @@ struct dat_provider_attr {
 	u32 dat_version_minor;
 	DAT_MEM_TYPE lmr_mem_types_supported;
 	DAT_IOV_OWNERSHIP iov_ownership_on_return;
-	DAT_QOS dat_qos_supported;
+	enum dat_qos dat_qos_supported;
 	DAT_COMPLETION_FLAGS completion_flags_supported;
 	boolean_t is_thread_safe;
 	int max_private_data_size;
@@ -1146,10 +1146,12 @@ typedef u32 (*DAT_EP_MODIFY_FUNC)(DAT_EP
 
 typedef u32 (*DAT_EP_CONNECT_FUNC)(DAT_EP_HANDLE, struct sockaddr *,
 				   DAT_CONN_QUAL, DAT_TIMEOUT, int,
-				   const void *, DAT_QOS, DAT_CONNECT_FLAGS);
+				   const void *, enum dat_qos,
+				   DAT_CONNECT_FLAGS);
 
 typedef u32 (*DAT_EP_DUP_CONNECT_FUNC)(DAT_EP_HANDLE, DAT_EP_HANDLE,
-				       DAT_TIMEOUT, int, const void *, DAT_QOS);
+				       DAT_TIMEOUT, int, const void *,
+				       enum dat_qos);
 
 typedef u32 (*DAT_EP_DISCONNECT_FUNC)(DAT_EP_HANDLE, DAT_CLOSE_FLAGS);
 
@@ -1494,7 +1496,7 @@ static inline u32 dat_evd_resize(DAT_EVD
 static inline u32 dat_ep_connect(DAT_EP_HANDLE ep, struct sockaddr *ia_addr,
 				 DAT_CONN_QUAL conn_qual, DAT_TIMEOUT timeout,
 				 int private_data_size,
-				 const void *private_data, DAT_QOS qos,
+				 const void *private_data, enum dat_qos qos,
 				 DAT_CONNECT_FLAGS flags)
 {
         return DAT_CALL_PROVIDER_FUNC(ep_connect_func, ep, ia_addr, conn_qual,
@@ -1532,7 +1534,7 @@ static inline u32 dat_ep_disconnect(DAT_
 
 static inline u32 dat_ep_dup_connect(DAT_EP_HANDLE ep, DAT_EP_HANDLE dup_ep,
 				     DAT_TIMEOUT timeout, int private_data_size,
-				     const void *private_data, DAT_QOS qos)
+				     const void *private_data, enum dat_qos qos)
 {
         return DAT_CALL_PROVIDER_FUNC(ep_dup_connect_func, ep, dup_ep, timeout, 
                                       private_data_size, private_data, qos);
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/dat-provider/dapl_ep_connect.c linux-kernel3/dat-provider/dapl_ep_connect.c
--- linux-kernel2/dat-provider/dapl_ep_connect.c	2005-05-13 11:10:25.786002000 -0700
+++ linux-kernel3/dat-provider/dapl_ep_connect.c	2005-05-13 12:33:26.934000000 -0700
@@ -46,7 +46,7 @@ u32 dapl_ep_connect(DAT_EP_HANDLE ep_han
 		    struct sockaddr *remote_ia_address,
 		    DAT_CONN_QUAL remote_conn_qual, DAT_TIMEOUT timeout,
 		    int private_data_size, const void *private_data,
-		    DAT_QOS qos, DAT_CONNECT_FLAGS connect_flags)
+		    enum dat_qos qos, DAT_CONNECT_FLAGS connect_flags)
 {
 	DAPL_EP *ep_ptr;
 	DAPL_EP alloc_ep;
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/dat-provider/dapl_ep_dup_connect.c linux-kernel3/dat-provider/dapl_ep_dup_connect.c
--- linux-kernel2/dat-provider/dapl_ep_dup_connect.c	2005-05-13 11:10:25.788006000 -0700
+++ linux-kernel3/dat-provider/dapl_ep_dup_connect.c	2005-05-13 12:33:26.936004000 -0700
@@ -71,7 +71,7 @@
  */
 u32 dapl_ep_dup_connect(DAT_EP_HANDLE ep_handle, DAT_EP_HANDLE ep_dup_handle,
 			DAT_TIMEOUT timeout, int private_data_size,
-			const void *private_data, DAT_QOS qos)
+			const void *private_data, enum dat_qos qos)
 {
 	DAPL_EP *ep_dup_ptr;
 	u32 dat_status;
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/dat-provider/dapl.h linux-kernel3/dat-provider/dapl.h
--- linux-kernel2/dat-provider/dapl.h	2005-05-13 11:38:08.137002000 -0700
+++ linux-kernel3/dat-provider/dapl.h	2005-05-13 12:33:26.930003000 -0700
@@ -560,14 +560,14 @@ extern u32 dapl_ep_connect(DAT_EP_HANDLE
 			   DAT_TIMEOUT timeout,
 			   int private_data_size,
 			   const void *private_data,
-			   DAT_QOS quality_of_service,
+			   enum dat_qos quality_of_service,
 			   DAT_CONNECT_FLAGS connect_flags);
 
 extern u32 dapl_ep_dup_connect(DAT_EP_HANDLE ep_handle,
 			       DAT_EP_HANDLE ep_dup_handle, DAT_TIMEOUT timeout,
 			       int private_data_size,
 			       const void *private_data,
-			       DAT_QOS quality_of_service);
+			       enum dat_qos quality_of_service);
 
 extern u32 dapl_ep_disconnect(DAT_EP_HANDLE ep_handle,
 			      DAT_CLOSE_FLAGS close_flags);
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_fft_cmd.h linux-kernel3/test/dapltest/include/dapl_fft_cmd.h
--- linux-kernel2/test/dapltest/include/dapl_fft_cmd.h	2005-05-11 08:51:30.515003000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_fft_cmd.h	2005-05-13 12:36:28.910012000 -0700
@@ -63,7 +63,7 @@ typedef struct
     int 		num_iter;	/* -i */
     int 		num_threads;	/* -t */
     int 		num_vis;	/* -v */
-    DAT_QOS		ReliabilityLevel; /* -R */
+    enum dat_qos	ReliabilityLevel; /* -R */
     DAT_MEM_TYPE 	DT_mem_type; /* -M */ 
 } FFT_Cmd_t;
 
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_limit_cmd.h linux-kernel3/test/dapltest/include/dapl_limit_cmd.h
--- linux-kernel2/test/dapltest/include/dapl_limit_cmd.h	2005-05-05 13:55:19.271974000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_limit_cmd.h	2005-05-13 12:36:53.685003000 -0700
@@ -52,7 +52,7 @@ typedef enum
 typedef struct
 {
     char 		device_name[256];	/* -D */
-    DAT_QOS		ReliabilityLevel;	/* -R */
+    enum dat_qos	ReliabilityLevel;	/* -R */
     uint32_t		width;			/* -w */
     uint32_t		debug;			/* -d */
     uint32_t		maximum;		/* -m */
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_params.h linux-kernel3/test/dapltest/include/dapl_params.h
--- linux-kernel2/test/dapltest/include/dapl_params.h	2005-05-11 08:51:30.518006000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_params.h	2005-05-13 12:33:26.960013000 -0700
@@ -61,7 +61,7 @@ typedef struct
     } u;
 
     /* Needed here due to structure of command processing */
-    DAT_QOS         ReliabilityLevel;
+    enum dat_qos         ReliabilityLevel;
     struct sockaddr   server_netaddr;
     void *	    phead;
     boolean_t     local_is_little_endian;
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_performance_cmd.h linux-kernel3/test/dapltest/include/dapl_performance_cmd.h
--- linux-kernel2/test/dapltest/include/dapl_performance_cmd.h	2005-05-05 13:54:46.392978000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_performance_cmd.h	2005-05-13 12:37:40.908007000 -0700
@@ -50,7 +50,7 @@ typedef struct {
     uint32_t   			client_is_little_endian;
     char            		server_name[NAME_SZ];	/* -s */
     char            		dapl_name[NAME_SZ];	/* -D */
-    DAT_QOS         		qos;
+    enum dat_qos       		qos;
     uint32_t   			debug;			/* -d */
     Performance_Mode_Type	mode;			/* -m */
     uint32_t      		num_iterations;		/* -i */
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_proto.h linux-kernel3/test/dapltest/include/dapl_proto.h
--- linux-kernel2/test/dapltest/include/dapl_proto.h	2005-05-13 11:37:44.339003000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_proto.h	2005-05-13 12:38:11.981004000 -0700
@@ -533,7 +533,7 @@ const char      *DT_EventToSTr (DAT_EVEN
 
 const char      *DT_State2Str (DAT_EP_STATE state_code);
 
-DAT_QOS         DT_ParseQoS (char *arg);
+enum dat_qos    DT_ParseQoS (char *arg);
 
 DAT_MEM_TYPE    DT_ParseMemType (char *arg);
 
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_quit_cmd.h linux-kernel3/test/dapltest/include/dapl_quit_cmd.h
--- linux-kernel2/test/dapltest/include/dapl_quit_cmd.h	2005-05-05 13:55:36.851973000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_quit_cmd.h	2005-05-13 12:33:26.970006000 -0700
@@ -34,7 +34,7 @@ typedef struct
     char		server_name[256];   /* -s */
     char		device_name[256];   /* -D */
     uint32_t 		debug;		    /* -d */
-    DAT_QOS     	ReliabilityLevel;   /* -R */
+    enum dat_qos     	ReliabilityLevel;   /* -R */
     DAT_MEM_TYPE 	DT_mem_type; /* -M */ 
 } Quit_Cmd_t;
 #pragma pack ()
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_server_cmd.h linux-kernel3/test/dapltest/include/dapl_server_cmd.h
--- linux-kernel2/test/dapltest/include/dapl_server_cmd.h	2005-05-11 08:52:07.427003000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_server_cmd.h	2005-05-13 12:38:35.892014000 -0700
@@ -32,9 +32,9 @@
 
 typedef struct
 {
-    boolean_t            debug;		/* -d */
+    boolean_t       debug;		/* -d */
     char            dapl_name[256];	/* -D device name */
-    DAT_QOS         ReliabilityLevel;	/* -R */
+    enum dat_qos    ReliabilityLevel;	/* -R */
     DAT_MEM_TYPE    DT_mem_type; /* -M */ 
 } Server_Cmd_t;
 #pragma pack ()
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/include/dapl_transaction_cmd.h linux-kernel3/test/dapltest/include/dapl_transaction_cmd.h
--- linux-kernel2/test/dapltest/include/dapl_transaction_cmd.h	2005-05-05 13:53:14.500974000 -0700
+++ linux-kernel3/test/dapltest/include/dapl_transaction_cmd.h	2005-05-13 12:33:26.976005000 -0700
@@ -55,7 +55,7 @@ typedef struct {
     uint32_t validate;		/* -V */
     uint32_t poll;		/* -P */
     char            dapl_name[NAME_SZ]; /* -D */
-    DAT_QOS         ReliabilityLevel;
+    enum dat_qos         ReliabilityLevel;
     uint32_t num_ops;
     Transaction_Cmd_Op_t op[MAX_OPS];
     DAT_MEM_TYPE    DT_mem_type; /* -M */




More information about the general mailing list
diff -Nurp -X /home/tduffy/dontdiff linux-kernel2/test/dapltest/cmd/dapl_qos_util.c linux-kernel3/test/dapltest/cmd/dapl_qos_util.c
--- linux-kernel2/test/dapltest/cmd/dapl_qos_util.c	2005-04-29 10:19:04.297007000 -0700
+++ linux-kernel3/test/dapltest/cmd/dapl_qos_util.c	2005-05-13 12:36:09.268006000 -0700
@@ -28,11 +28,11 @@
 #include "dapl_proto.h"
 
 /*
  * Parse a QOS argument into a DAT_QOS.
  *
  * Returns no errors: defaults to best effort.
  */
-DAT_QOS
+enum dat_qos
 DT_ParseQoS (char *arg)
 {
     if (0 == strcmp (arg, "HT"))
@@ -28,11 +28,11 @@
 
 /*
- * Parse a QOS argument into a DAT_QOS.
+ * Parse a QOS argument into an enum dat_qos.
  *
  * Returns no errors: defaults to best effort.